# testpackagemds 0.1.0
A package created to try a GitHub Actions workflow!

## Installation

```bash
$ pip install testpackagemds
```

## Usage



## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`testpackagemds` was created by Florencia. It is licensed under the terms of the MIT license.

## Credits

`testpackagemds` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
